@@ -9,10 +9,12 @@
 #ifndef SYSOURCE_H
 #define SYSOURCE_H
 
-#include <QtCore/QString>
-#include <QtNetwork/QHostAddress>
+#include <QHostAddress>
+#include <QString>
 
-class SySource
+#include <sy/syendpoint.h>
+
+class SySource : public SyEndPoint
 {
  public:
   SySource(const QHostAddress &s_addr,const QString &name,bool enabled);
@@ -21,6 +23,8 @@ class SySource
   void setStreamAddress(const QHostAddress &addr);
   QString name() const;
   void setName(const QString &name);
+  QString label() const;
+  void setLabel(const QString &str);
   bool enabled() const;
   void setEnabled(bool state);
   unsigned channels() const;
@@ -33,6 +37,7 @@ class SySource
  private:
   QHostAddress src_stream_address;
   QString src_name;
+  QString src_label;
   bool src_enabled;
   unsigned src_channels;
   unsigned src_packet_size;
